@@ -215,7 +215,7 @@
     
   for(i=0; (agent = [index next]); i++)
     {
-      position[i] = [agent getPosition];
+      position[i] = [agent getAgentPosition];
       wealth[i] = [agent getWealth];
       //cash[i] = [agent getCash];
       relativeWealth[i] = wealth[i]/[asmModelSwarm getInitialCash];
