@@ -64,13 +64,12 @@
 // 
 
 #import "BFagent.h"
-#import <stdlib.h>
-#import <math.h>
-#import <string.h>
-#import <malloc.h>
 #import "random.h"
 #import "World.h"
 
+#include <misc.h>
+#include <math.h>
+
 World * worldForAgent;
 
 //Macros for bittables
