@@ -106,11 +106,10 @@
 
 
 #import "World.h"
-#import <math.h>
-#import <string.h>
-#import <malloc.h>   //For calloc
 #import "random.h"
 
+#include <math.h>
+#include <misc.h>
 
 // List of bit names and descriptions
 // NB: If you change the order or meaning of bits, also check or change:
